==> mlr3torch_0.1.2.tar.gz: mlr3torch/R/bibentries.R <==
bibentries = c(# nolint start
  gorishniy2021revisiting = bibentry("article",
    title = "Revisiting Deep Learning  for Tabular Data",
    author = "Yury Gorishniy and Ivan Rubachev and Valentin Khrulkov and Artem Babenko",
    journal = "arXiv",
    volume = "2106.11959",
    year = "2021",
  ),
  devlin2018bert = bibentry("article",
    title = "Bert: Pre-training of deep bidirectional transformers for language understanding",
    author = "Devlin, Jacob and Chang, Ming-Wei and Lee, Kenton and Toutanova, Kristina",
    journal = "arXiv preprint arXiv:1810.04805",
    year = "2018"
  ),
  vaswani2017attention = bibentry("article",
    title = "Attention is all you need",
    author = "Vaswani, Ashish and Shazeer, Noam and Parmar, Niki and Uszkoreit, Jakob and Jones, Llion and Gomez, Aidan N and Kaiser, \xc5\x81ukasz and Polosukhin, Illia",
    journal = "Advances in neural information processing systems",
    volume = "30",
    year = "2017"
  ),
  arik2021tabnet = bibentry("inproceedings",
    title = "Tabnet: Attentive interpretable tabular learning",
    author = "Ar\xc4\xb1k, Sercan O and Pfister, Tomas",
    booktitle = "AAAI",
    volume = "35",
    pages = "6679--6687",
    year = "2021"
  ),

  ioffe2015batch = bibentry("inproceedings",
    title = "Batch normalization: Accelerating deep network training by reducing internal covariate shift",
    author = "Ioffe, Sergey and Szegedy, Christian",
    booktitle = "International conference on machine learning",
    pages = "448--456",
    year = "2015",
    organization = "PMLR"
  ),
  krizhevsky2017imagenet = bibentry(
    "article",
    title = "Imagenet classification with deep convolutional neural networks",
    author = c("Krizhevsky, Alex", "Sutskever, Ilya", "Hinton, Geoffrey E."),
    journal = "Communications of the ACM",
    volume = "60",
    number = "6",
    pages = "84--90",
    year = "2017",
    publisher = "Association for Computing Machinery (ACM)"
  ),
  imagenet2009 = bibentry(
    bibtype = "InProceedings",
    textVersion = "Deng, J. et al. (2009). Imagenet: A large-scale hierarchical image database. In Proceedings of the 2009 IEEE conference on computer vision and pattern recognition (pp. 248--255). IEEE.",
    header = "deng2009imagenet",
    title = "Imagenet: A large-scale hierarchical image database",
    author = c("Deng, Jia", "Dong, Wei", "Socher, Richard", "Li, Li-Jia", "Li, Kai", "Fei-Fei, Li"),
    booktitle = "2009 IEEE conference on computer vision and pattern recognition",
    pages = "248--255",
    year = "2009",
    organization = "IEEE"
  ),
  mnist = bibentry("article",
    author='Lecun, Y. and Bottou, L. and Bengio, Y. and Haffner, P.',
    journal='Proceedings of the IEEE',
    title='Gradient-based learning applied to document recognition',
    year='1998',
    volume='86',
    number='11',
    pages='2278-2324',
    doi='10.1109/5.726791'
  ),
  anderson_1936 = bibentry("article",
    doi       = "10.2307/2394164",
    year      = "1936",
    month     = "9",
    publisher = "JSTOR",
    volume    = "23",
    number    = "3",
    pages     = "457",
    author    = "Edgar Anderson",
    title     = "The Species Problem in Iris",
    journal   = "Annals of the Missouri Botanical Garden"
  ),
  sandler2018mobilenetv2 = bibentry("InProceedings",
    title    = "Mobilenetv2: Inverted residuals and linear bottlenecks",
    author   = "Sandler, Mark and Howard, Andrew and Zhu, Menglong and Zhmoginov, Andrey and Chen, Liang-Chieh",
    booktitle= "Proceedings of the IEEE conference on computer vision and pattern recognition",
    pages    = "4510--4520",
    year     = "2018"
  ),
  simonyan2014very = bibentry("article",
    title  = "Very deep convolutional networks for large-scale image recognition",
    author = "Simonyan, Karen and Zisserman, Andrew",
    journal= "arXiv preprint arXiv:1409.1556",
    year   = "2014"
  ),
  he2016deep = bibentry("InProceedings",
    title     = "Deep residual learning for image recognition ",
    author    = "He, Kaiming and Zhang, Xiangyu and Ren, Shaoqing and Sun, Jian ",
    booktitle = "Proceedings of the IEEE conference on computer vision and pattern recognition ",
    pages     = "770--778 ",
    year      = "2016 "
  ),
  krizhevsky2014one = bibentry("article",
    title = "One weird trick for parallelizing convolutional neural networks",
    author = "Krizhevsky, Alex",
    journal = "arXiv preprint arXiv:1404.5997",
    year = "2014"
  ),
  szegedy2016rethinking = bibentry("InProceedings",
    title     = "Rethinking the inception architecture for computer vision ",
    author    = "Szegedy, Christian and Vanhoucke, Vincent and Ioffe, Sergey and Shlens, Jon and Wojna, Zbigniew ",
    booktitle = "Proceedings of the IEEE conference on computer vision and pattern recognition ",
    pages     = "2818--2826 ",
    year      = "2016 "
  )
) # nolint end

==> mlr3torch_0.2.0.tar.gz: mlr3torch/R/bibentries.R <==
bibentries = c(# nolint start
  gorishniy2021revisiting = bibentry("article",
    title = "Revisiting Deep Learning  for Tabular Data",
    author = "Yury Gorishniy and Ivan Rubachev and Valentin Khrulkov and Artem Babenko",
    journal = "arXiv",
    volume = "2106.11959",
    year = "2021",
  ),
  devlin2018bert = bibentry("article",
    title = "Bert: Pre-training of deep bidirectional transformers for language understanding",
    author = "Devlin, Jacob and Chang, Ming-Wei and Lee, Kenton and Toutanova, Kristina",
    journal = "arXiv preprint arXiv:1810.04805",
    year = "2018"
  ),
  vaswani2017attention = bibentry("article",
    title = "Attention is all you need",
    author = "Vaswani, Ashish and Shazeer, Noam and Parmar, Niki and Uszkoreit, Jakob and Jones, Llion and Gomez, Aidan N and Kaiser, \xc5\x81ukasz and Polosukhin, Illia",
    journal = "Advances in neural information processing systems",
    volume = "30",
    year = "2017"
  ),
  arik2021tabnet = bibentry("inproceedings",
    title = "Tabnet: Attentive interpretable tabular learning",
    author = "Ar\xc4\xb1k, Sercan O and Pfister, Tomas",
    booktitle = "AAAI",
    volume = "35",
    pages = "6679--6687",
    year = "2021"
  ),

  ioffe2015batch = bibentry("inproceedings",
    title = "Batch normalization: Accelerating deep network training by reducing internal covariate shift",
    author = "Ioffe, Sergey and Szegedy, Christian",
    booktitle = "International conference on machine learning",
    pages = "448--456",
    year = "2015",
    organization = "PMLR"
  ),
  krizhevsky2017imagenet = bibentry(
    "article",
    title = "Imagenet classification with deep convolutional neural networks",
    author = c("Krizhevsky, Alex", "Sutskever, Ilya", "Hinton, Geoffrey E."),
    journal = "Communications of the ACM",
    volume = "60",
    number = "6",
    pages = "84--90",
    year = "2017",
    publisher = "Association for Computing Machinery (ACM)"
  ),
  imagenet2009 = bibentry(
    bibtype = "InProceedings",
    textVersion = "Deng, J. et al. (2009). Imagenet: A large-scale hierarchical image database. In Proceedings of the 2009 IEEE conference on computer vision and pattern recognition (pp. 248--255). IEEE.",
    header = "deng2009imagenet",
    title = "Imagenet: A large-scale hierarchical image database",
    author = c("Deng, Jia", "Dong, Wei", "Socher, Richard", "Li, Li-Jia", "Li, Kai", "Fei-Fei, Li"),
    booktitle = "2009 IEEE conference on computer vision and pattern recognition",
    pages = "248--255",
    year = "2009",
    organization = "IEEE"
  ),
  mnist = bibentry("article",
    author='Lecun, Y. and Bottou, L. and Bengio, Y. and Haffner, P.',
    journal='Proceedings of the IEEE',
    title='Gradient-based learning applied to document recognition',
    year='1998',
    volume='86',
    number='11',
    pages='2278-2324',
    doi='10.1109/5.726791'
  ),
  anderson_1936 = bibentry("article",
    doi       = "10.2307/2394164",
    year      = "1936",
    month     = "9",
    publisher = "JSTOR",
    volume    = "23",
    number    = "3",
    pages     = "457",
    author    = "Edgar Anderson",
    title     = "The Species Problem in Iris",
    journal   = "Annals of the Missouri Botanical Garden"
  ),
  sandler2018mobilenetv2 = bibentry("InProceedings",
    title    = "Mobilenetv2: Inverted residuals and linear bottlenecks",
    author   = "Sandler, Mark and Howard, Andrew and Zhu, Menglong and Zhmoginov, Andrey and Chen, Liang-Chieh",
    booktitle= "Proceedings of the IEEE conference on computer vision and pattern recognition",
    pages    = "4510--4520",
    year     = "2018"
  ),
  simonyan2014very = bibentry("article",
    title  = "Very deep convolutional networks for large-scale image recognition",
    author = "Simonyan, Karen and Zisserman, Andrew",
    journal= "arXiv preprint arXiv:1409.1556",
    year   = "2014"
  ),
  he2016deep = bibentry("InProceedings",
    title     = "Deep residual learning for image recognition ",
    author    = "He, Kaiming and Zhang, Xiangyu and Ren, Shaoqing and Sun, Jian ",
    booktitle = "Proceedings of the IEEE conference on computer vision and pattern recognition ",
    pages     = "770--778 ",
    year      = "2016 "
  ),
  krizhevsky2014one = bibentry("article",
    title = "One weird trick for parallelizing convolutional neural networks",
    author = "Krizhevsky, Alex",
    journal = "arXiv preprint arXiv:1404.5997",
    year = "2014"
  ),
  szegedy2016rethinking = bibentry("InProceedings",
    title     = "Rethinking the inception architecture for computer vision ",
    author    = "Szegedy, Christian and Vanhoucke, Vincent and Ioffe, Sergey and Shlens, Jon and Wojna, Zbigniew ",
    booktitle = "Proceedings of the IEEE conference on computer vision and pattern recognition ",
    pages     = "2818--2826 ",
    year      = "2016 "
  ),
  melanoma2021 = bibentry("article",
    title = "A patient-centric dataset of images and metadata for identifying melanomas using clinical context",
    author = "Rotemberg, V. and Kurtansky, N. and Betz-Stablein, B. and Caffery, L. and Chousakos, E. and Codella, N. and Combalia, M. and Dusza, S. and Guitera, P. and Gutman, D. and Halpern, A. and Helba, B. and Kittler, H. and Kose, K. and Langer, S. and Lioprys, K. and Malvehy, J. and Musthaq, S. and Nanda, J. and Reiter, O. and Shih, G. and Stratigos, A. and Tschandl, P. and Weber, J. and Soyer, P.",
    journal = "Scientific Data",
    volume = "8",
    pages = "34",
    year = "2021",
    doi = "10.1038/s41597-021-00815-z"
  ),
  cifar2009 = bibentry("article",
    title = "Learning Multiple Layers of Features from Tiny Images",
    author = "Krizhevsky, Alex",
    journal= "Master's thesis, Department of Computer Science, University of Toronto",,
    year = "2009",
  )
) # nolint end
